<?php

require __DIR__.'/../sdk/autoload.php';

use Initpro\KassaSdk\Check;
use Initpro\KassaSdk\Position;
use Initpro\KassaSdk\Vat;
use Initpro\KassaSdk\Client;
use Initpro\KassaSdk\GroupManager;
use Initpro\KassaSdk\Payment;

class initproKassaFiscalizer
{
    /** @var modX $modx */
    public $modx;

    /**
     * @param modX $modx
     * @param array $config
     */
    function __construct(modX &$modx, array $config = array())
    {
        $this->modx =& $modx;
        $this->config = array_merge(array(
            'shop_id' => $this->modx->getOption('initprokassa_shop_id'),
            'queue_id' => $this->modx->getOption('initprokassa_queue_id'),
            'secret' => $this->modx->getOption('initprokassa_secret'),
            'is_print_check' => $this->modx->getOption('initprokassa_is_print_check', null, true),
            'sno' => $this->modx->getOption('initprokassa_sno'),
            'server_url' => $this->modx->getOption('initprokassa_host')
        ), $config);
    }


    public function fiscalize($order, $is_refund = false, $uniqid)
    {
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Check.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Client.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Payment.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Position.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/GroupManager.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Vat.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Exception/ClientException.php';
        include_once dirname(dirname(__FILE__)) . '/sdk/src/Exception/SdkException.php';

        $user = $order->getOne('UserProfile');

        // Параметры для фискализации берутся из настроек компонента
        $checkParams = array(
            'id' => (string)$order->get('id'),
            'shop_id' => $this->config['shop_id'],
            'queue_id' => $this->config['queue_id'],
            'secret' => $this->config['secret'],
            'is_print_check' => $this->config['is_print_check'],
            'sno' => $this->config['sno'],
        );

        // Создается способ оплаты чека
        $payment = new Payment(Payment::TYPE_CARD, round($order->get('cost'), 2));

        // Создается чек

        $check_method = $is_refund ? Check::INTENT_SELL_RETURN : Check::INTENT_SELL;

        // $uniqid = uniqid(strval($checkParams['id']), true);
        
        $check = new Check($uniqid, $user->email, $check_method, intval($checkParams['sno']));
        $check->setShouldPrint($checkParams['is_print_check']);
        $check->addPayment($payment);

        // Достаются позиции из заказа
        $positions = $order->getMany('Products');

        $defaultVat = new Vat(Vat::RATE_NO);
        // Создаются позиции чека
        foreach($positions as $position) {
            $opts = $position->get('options');
            if (!$opts['vat']) {
                $vat = $defaultVat;
            }
            else {
                $vat = $opts['vat'];
            }

            $positionObj = new Position($position->name,
                                        floatval($position->price),
                                        floatval($position->count),
                                        $position->count*$position->price,
                                        floatval($position->order_discount),
                                        $vat);
            $check->addPosition($positionObj);
        }

        // Позиция стоимости доставки
        if (floatval($order->delivery_cost) > 0) {
            $shippingPosition = new Position("Доставка",
                                             floatval($order->delivery_cost),
                                             1,
                                             floatval($order->delivery_cost),
                                             0,
                                             new Vat(Vat::RATE_NO));
            $check->addPosition($shippingPosition);
        }

        // Создается клиент для подключения к ИНИТПРО кассе
        $client = new Client($checkParams['shop_id'], $checkParams['secret']);

        if (@$this->config['server_url']) {
            $client->setHost( $this->config['server_url'] );
        }
        
        $manager = new GroupManager($client);
        $manager->registerGroup('default', $checkParams['queue_id']);
        $manager->setDefaultGroup('default');

        // Отправка на фискализацию
        try {
            $manager->putCheck($check);
        } catch (SdkException $e) {
            $this->$modx->log(modX::ERROR, 'SdkException: '.$e->getMessage());
        }
    }
}